# Description
A simple, declarative oriented framework to create WinForms in Python.

While it can be used for all kinds of forms, it was created with the purpose of being applied in Robotics, where the need to visualize complex algorithms and, above all, observe the effect of parameter changes is very common.

The forms are defined in a declarative way in an YAML (layouts, controls, toolbar, menus, etc.) and used in a Python program with just a few lines of code.

# How to use it
The best way to learn how to use it is just take a look at the code.

For a complete form see `view_example.yaml` to understand how the form is defined and `view_example.py` how it is used.

If you run `python view_example.py` the form is: 

<img width="997" alt="winform_example" src="https://github.com/njodal/WIndow_form/assets/28706901/ab02ce1f-9409-454d-8d95-e130fe6d77ed">

In case a simple graph is needed look at `view_simple_graph.py`.
# Examples

## Form used to tune a PID controller for control a model car

<img width="1003" alt="PID tuning" src="https://github.com/njodal/WIndow_form/assets/28706901/c978edfc-808b-47d4-993c-22d00b7fd154">





